@@ -9,8 +9,8 @@ use crate::spec::chart::{ChartSpec, ChartVisitor};
 use crate::spec::data::{DataFormatParseSpec, DataSpec};
 use crate::spec::mark::{MarkFacetSpec, MarkSpec};
 use crate::spec::scale::{
-    ScaleArrayElementSpec, ScaleBinsSpec, ScaleDataReferenceSpec, ScaleDomainSpec, ScaleRangeSpec,
-    ScaleSpec,
+    ScaleArrayElementSpec, ScaleBinsSpec, ScaleDataReferenceOrSignalSpec, ScaleDomainSpec,
+    ScaleFieldReferenceSpec, ScaleRangeSpec, ScaleSpec,
 };
 use crate::spec::signal::{SignalOnEventSpec, SignalSpec};
 use crate::spec::values::{SignalExpressionSpec, StringOrSignalSpec};
@@ -203,7 +203,7 @@ impl<'a> ChartVisitor for MakeTasksVisitor<'a> {
             )
         } else {
             let values_table = match data.values.as_ref() {
-                Some(values) => VegaFusionTable::from_json(values, 1024)?,
+                Some(values) => VegaFusionTable::from_json(values)?,
                 None => {
                     // Treat as empty values array
                     VegaFusionTable::empty_with_ordering()
@@ -550,7 +550,7 @@ impl<'a> ChartVisitor for InputVarsChartVisitor<'a> {
     }
 
     fn visit_scale(&mut self, scale: &ScaleSpec, scope: &[u32]) -> Result<()> {
-        let mut references: Vec<ScaleDataReferenceSpec> = Vec::new();
+        let mut references: Vec<ScaleFieldReferenceSpec> = Vec::new();
         let mut signals: Vec<SignalExpressionSpec> = Vec::new();
 
         // domain
@@ -559,8 +559,20 @@ impl<'a> ChartVisitor for InputVarsChartVisitor<'a> {
                 ScaleDomainSpec::FieldReference(reference) => {
                     references.push(reference.clone());
                 }
-                ScaleDomainSpec::FieldsReference(field_references) => {
-                    references.extend(field_references.fields.clone());
+                ScaleDomainSpec::FieldsReference(fields_reference) => {
+                    references.extend(fields_reference.to_field_references());
+                }
+                ScaleDomainSpec::FieldsReferences(field_references) => {
+                    for v in field_references.fields.clone() {
+                        match v {
+                            ScaleDataReferenceOrSignalSpec::Reference(field_ref) => {
+                                references.push(field_ref);
+                            }
+                            ScaleDataReferenceOrSignalSpec::Signal(signal) => {
+                                signals.push(signal);
+                            }
+                        }
+                    }
                 }
                 ScaleDomainSpec::FieldsSignals(fields_signals) => {
                     signals.extend(fields_signals.fields.clone());
