@@ -288,7 +288,7 @@ impl FieldSpec {
                 })
             }
             _ => {
-                if is_numeric_datatype(field_type) && !is_numeric_datatype(&scalar.get_datatype()) {
+                if is_numeric_datatype(field_type) && !is_numeric_datatype(&scalar.data_type()) {
                     cast_to(lit(scalar), field_type, schema)
                 } else {
                     Ok(lit(scalar))
